import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ComponentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Default assignee type. Can be one of project_default, component_lead, project_lead or unassigned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#assignee_type Component#assignee_type}
    */
    readonly assigneeType?: string;
    /**
    * Description of the component
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#description Component#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#id Component#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Component lead
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#lead Component#lead}
    */
    readonly lead?: string;
    /**
    * Name of the component
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#name Component#name}
    */
    readonly name: string;
    /**
    * Project Key (for example PRJ)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#project_key Component#project_key}
    */
    readonly projectKey: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component jira_component}
*/
export declare class Component extends cdktf.TerraformResource {
    static readonly tfResourceType = "jira_component";
    /**
    * Generates CDKTF code for importing a Component resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Component to import
    * @param importFromId The id of the existing Component that should be imported. Refer to the {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Component to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/component jira_component} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ComponentConfig
    */
    constructor(scope: Construct, id: string, config: ComponentConfig);
    private _assigneeType?;
    get assigneeType(): string;
    set assigneeType(value: string);
    resetAssigneeType(): void;
    get assigneeTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _lead?;
    get lead(): string;
    set lead(value: string);
    resetLead(): void;
    get leadInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
