import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IssueConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#assignee Issue#assignee}
    */
    readonly assignee?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#delete_transition Issue#delete_transition}
    */
    readonly deleteTransition?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#description Issue#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#fields Issue#fields}
    */
    readonly fields?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#id Issue#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#issue_type Issue#issue_type}
    */
    readonly issueType: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#labels Issue#labels}
    */
    readonly labels?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#project_key Issue#project_key}
    */
    readonly projectKey: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#reporter Issue#reporter}
    */
    readonly reporter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#state Issue#state}
    */
    readonly state?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#state_transition Issue#state_transition}
    */
    readonly stateTransition?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#summary Issue#summary}
    */
    readonly summary: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue jira_issue}
*/
export declare class Issue extends cdktf.TerraformResource {
    static readonly tfResourceType = "jira_issue";
    /**
    * Generates CDKTF code for importing a Issue resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Issue to import
    * @param importFromId The id of the existing Issue that should be imported. Refer to the {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Issue to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs/resources/issue jira_issue} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IssueConfig
    */
    constructor(scope: Construct, id: string, config: IssueConfig);
    private _assignee?;
    get assignee(): string;
    set assignee(value: string);
    resetAssignee(): void;
    get assigneeInput(): string | undefined;
    private _deleteTransition?;
    get deleteTransition(): string;
    set deleteTransition(value: string);
    resetDeleteTransition(): void;
    get deleteTransitionInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _fields?;
    get fields(): {
        [key: string]: string;
    };
    set fields(value: {
        [key: string]: string;
    });
    resetFields(): void;
    get fieldsInput(): {
        [key: string]: string;
    } | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get issueKey(): string;
    private _issueType?;
    get issueType(): string;
    set issueType(value: string);
    get issueTypeInput(): string | undefined;
    private _labels?;
    get labels(): string[];
    set labels(value: string[]);
    resetLabels(): void;
    get labelsInput(): string[] | undefined;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    private _reporter?;
    get reporter(): string;
    set reporter(value: string);
    resetReporter(): void;
    get reporterInput(): string | undefined;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
    private _stateTransition?;
    get stateTransition(): string;
    set stateTransition(value: string);
    resetStateTransition(): void;
    get stateTransitionInput(): string | undefined;
    private _summary?;
    get summary(): string;
    set summary(value: string);
    get summaryInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
