import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface JiraProviderConfig {
    /**
    * Password for the user, can also be an API Token. Can be specified with the JIRA_PASSWORD environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs#password JiraProvider#password}
    */
    readonly password?: string;
    /**
    * Personal access token of a user. Can be specified with the JIRA_TOKEN environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs#token JiraProvider#token}
    */
    readonly token?: string;
    /**
    * URL for your Jira instance. Can be specified with the JIRA_URL environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs#url JiraProvider#url}
    */
    readonly url: string;
    /**
    * Username for your user. Can be specified with the JIRA_USER environment variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs#user JiraProvider#user}
    */
    readonly user?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs#alias JiraProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs jira}
*/
export declare class JiraProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "jira";
    /**
    * Generates CDKTF code for importing a JiraProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the JiraProvider to import
    * @param importFromId The id of the existing JiraProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the JiraProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/fourplusone/jira/0.1.20/docs jira} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options JiraProviderConfig
    */
    constructor(scope: Construct, id: string, config: JiraProviderConfig);
    private _password?;
    get password(): string | undefined;
    set password(value: string | undefined);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _url?;
    get url(): string | undefined;
    set url(value: string | undefined);
    get urlInput(): string | undefined;
    private _user?;
    get user(): string | undefined;
    set user(value: string | undefined);
    resetUser(): void;
    get userInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
